@@ -178,6 +178,28 @@ def describe_stack(cloudformation, cluster):
     )
     return response
 
+def describe_stack_dynamically(cloudformation, cluster):
+    try:
+        # cloudformation = boto3.client('cloudformation')
+        # stack_name = "%s-eks-worker-nodes" % (args.environment)
+        response = cloudformation.describe_stacks()
+
+        clusterStackNames = []
+        stacksINFO = []
+        for counter in xrange(len(response['Stacks'])):
+            # print(len(response['Stacks']))
+            stackName = response['Stacks'][counter]['StackName']
+            if(args.environment in stackName):
+                clusterStackNames.append(stackName)
+                # print(response['Stacks'][counter])
+                stacksINFO.append(response['Stacks'][counter])
+                # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
+
+        # print(clusterStackNames)
+        return stacksINFO
+    except:
+        pass
+
 def cahc(cluster):
     eks = eks()
     clusterINFO = describe_cluster(eks, cluster)
@@ -204,17 +226,16 @@ def times():
 
     return {'day': day, 'month': month, 'date': date, 'year': year}
 
-newLine = False
 printLogMsg = False
-def logger(logFile, logMsg, newLine, printLogMsg):
+def logger(logFile, logMsg, printLogMsg, newLine):
     """ 
     Logger for calling program. 
     
     Parameters:
     logFile (str): File to be logged to
     logMsg (str): Message to be logged
-    newLine (bool): Option to prepend newline
     printLogMsg (bool): Option to print log message
+    newLine (str): Option to prepend newline to the top, both or bottom only
   
     Returns: 
     int: Description of return value 
@@ -226,7 +247,9 @@ def logger(logFile, logMsg, newLine, printLogMsg):
     program = sys.argv[0]
     program = program.rsplit('/', 1)[-1]\
     
-    if(newLine is True):
-        logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg))
-    else:
+    if(newLine == 'top'):
+        logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg))    
+    elif(newLine == 'both'):
+        logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + '\n')   
+    elif(newLine == 'bottom'):
         logFile.write(str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + '\n')
\ No newline at end of file
